from typing import List
import pandas as pd
import asyncio
from retarus.sms.client import SmsClient
from retarus.sms.model import SmsJob, Messages, Recipient
from retarus.commons.config import Configuration
import os
import json
from pathlib import Path
from datetime import datetime

Configuration.set_auth(os.environ["retarus_userid"], os.environ["retarus_sms_password"])

async_sdk = SmsClient(True)


async def send_sms_jobs(jobs: List[SmsJob]):    
    res_futures = []
    for job in jobs:
        res = asyncio.ensure_future(async_sdk.client.send_sms(job))
        res_futures.append(res)
    return await asyncio.gather(*res_futures)


async def get_sms_reports(ids: list[str]):
    res_futures = []
    for x in ids:
        res = asyncio.ensure_future(async_sdk.client.get_sms_job(x["jobId"]))
        res_futures.append(res)
    return await asyncio.gather(*res_futures)


def write_reports(reports: list):
    # save the reports on the local machine
    time = datetime.utcnow()
    path = f"in/{time}-report.json"
    with open(path, "w+") as file:
        json.dump(reports, file)


async def main():

    prepared_jobs: List[SmsJob] = []
    df = pd.read_csv("assets/sms_data.csv", converters={'number': str})
    for data in df.values:
        recipient = Recipient(dst=data[2])
        firstname = data[1]
        message = Messages(
            text=f"Hello {firstname}, Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem",
            recipients=[recipient],
        )
        job = SmsJob(messages=[message])
        prepared_jobs.append(job)
    job_ids = asyncio.ensure_future(send_sms_jobs(prepared_jobs))
    await job_ids
    
    reports = []
    
    # delay for the server to process the jobs and create the reports
    await asyncio.sleep(2)
    reports = asyncio.ensure_future(get_sms_reports(job_ids.result()))
    await reports

    write_reports(reports.result())


if __name__ == "__main__":
    asyncio.run(main())



import asyncio
from ._async import AsyncSmsClient
from .model import Client, SmsJob


class SyncSmsClient(Client):
    def __init__(self, uris):
        self.client = AsyncSmsClient(uris)
        self.loop = asyncio.new_event_loop()

    def send_sms(self, sms: SmsJob):
        res = self.loop.run_until_complete(self.client.send_sms(sms))
        return res

    def get_sms_job(self, job_id: str) -> dict:
        res = self.loop.run_until_complete(self.client.get_sms_job(job_id))
        return res

    def filter_sms_jobs(self, *args, **kwargs):
        """
        Gets all sms reports that match the given criteria.

        Parameters:
        job_ids_only: bool
        from_ts: str (e.g. 2018-06-13T00:00+02:00) can only be max 30 days before to_ts
        to_ts: str (e.g. 2018-06-20T00:00+02:00)
        open: bool
        offset: int (default: 0)
        limit: int (default: 100)
        """
        res = self.loop.run_until_complete(self.client.filter_sms_jobs(**kwargs))
        return res

    def server_version(self):
        res = self.loop.run_until_complete(self.client.server_version())
        return res



from typing import List
import pandas as pd
import os
from dotenv import load_dotenv 

from retarus.sms.client import SmsClient
from retarus.sms.model import SmsJob, Messages, Recipient
from retarus.commons.config import Configuration


def initialize():
    Configuration.set_auth(os.environ["retarus_userid"], os.environ["retarus_sms_password"])
    jobs: List[SmsJob] = []
    df = pd.read_csv("assets/sms_data.csv", converters={'number': str})
    for data in df.values:
        recipient = Recipient(dst=data[2])
        firstname = data[1]
        message = Messages(
            text=f"Hello {firstname}, Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem",
            recipients=[recipient],
        )
        job = SmsJob(messages=[message])
        jobs.append(job)

    return jobs

def main():
    jobs = initialize()
    sdk = SmsClient()
    for job in jobs:
        res = sdk.client.send_sms(job)
        print(res)



if __name__ == '__main__':
    main()


import pytest
import os

from retarus.sms.client import SmsClient
from retarus.sms.model import SmsJob
from retarus.commons.config import Configuration
from retarus.commons.exceptions import ConfigurationError


sdk = SmsClient(is_async=True)

jobIds = []
def init():
    Configuration.set_auth(os.environ["retarus_userid"], os.environ["retarus_sms_password"])


@pytest.mark.asyncio
async def test_authentication_validation():
    Configuration.auth = {}
    error = {}
    try:
        res = await sdk.client.filter_sms_jobs(job_ids_only=True, limit=2)
    except Exception as e:
        error = e

    if error == {}:
        assert False


@pytest.mark.asyncio
async def test_server_version():
    init()

    res = await sdk.client.server_version()
    print(res)
    assert isinstance(res, dict)


@pytest.mark.asyncio
async def test_Send_sms():
    global jobIds
    init()
    sms = SmsJob.minimal("+4917600000000", "Hallo Welt")
    res = await sdk.client.send_sms(sms)
    print(res)

    sms = SmsJob.minimal("+4917600000000", "Hallo Welt")
    res = await sdk.client.send_sms(sms)

@pytest.mark.asyncio
async def test_filter_sms_jobs():
    init()
    
    res = await sdk.client.filter_sms_jobs(job_ids_only=True, limit=1)
    print(res)
    if len(res) != 1:
        assert False



sync_sdk = SmsClient()

def test_sync_client():
    init()
    res = sync_sdk.client.filter_sms_jobs(limit=1, job_ids_only=True)
    print(res)
    if len(res) != 1:
        assert False



from retarus.commons.transport import Transporter
from .model import Client, SmsJob
from retarus.commons.utils import to_camel_case


class AsyncSmsClient(Client):

    def __init__(self, uris):
        self.transporter = Transporter(uris)

    async def send_sms(self, sms: SmsJob):
        data = sms.exclude_optional_dict()
        url = "/jobs"
        res = await self.transporter.post(url, data)
        return res

    async def get_sms_job(self, job_id: str):
        path = f"jobs/{job_id}"
        res = await self.transporter.get(path)
        return res

    async def filter_sms_jobs(self, *args, **kwargs):
        """
        Gets all sms reports that match the given criteria.

        Parameters:
        job_ids_only: bool
        from_ts: str (e.g. 2018-06-13T00:00+02:00) can only be max 30 days before to_ts
        to_ts: str (e.g. 2018-06-20T00:00+02:00)
        open: bool
        offset: int (default: 0)
        limit: int (default: 100)
        """
        path = "jobs"
        parms = {}
        for key, value in kwargs.items():
            parms[to_camel_case(key)] = str(value) if isinstance(value, bool) else value
        res = await self.transporter.get(path, query_parms=parms)
        return res

    async def server_version(self) -> dict:
        """
        Get current server version and build information.
        """
        path = "version"
        res = await self.transporter.get(path)
        return res



from typing import List
import pandas as pd
import asyncio
import os
from dotenv import load_dotenv 

from retarus.sms.client import SmsClient
from retarus.sms.model import SmsJob, Messages, Recipient
from retarus.commons.config import Configuration


'''
How to use this example
1. Setup the SDK like described in the README file on top level of the repository. If 
   you need additonal help, please have a look at our OpenAPI here: 
   https://developers.retarus.com/docs/sms/api/sms-sending-api/
2. Create an .env file somewhere in your project. It must at least contain key / value
   pairs of "retarus_userid" and "retarus_sms_password". You need the values to
   authenticate as can be seen below. An entry looks like this:
   retarus_userid=user123
   We recommend to create the .env file on the same level as this script.
3. This example will overtake the contacts from the sms_data.csv in the assets folder 
   in the sms examples. Please replace the recipient numbers by your own one(s) to see a
   result when you send the SMS.
4. When you are satisfied with your settings, execute this script. As a confirmation,
   this example prints the job ID that you can use to check it's status. Please see
   our example 'get_status_async.py' for details on getting a status. Feel free to adjust
   the status handling in the way you like it. For example, you could report it in a
   logger and then save it to a log file.
'''


def initialize():
    Configuration.set_auth(os.environ["retarus_userid"], os.environ["retarus_sms_password"])
    jobs: List[SmsJob] = []
    df = pd.read_csv("assets/sms_data.csv", converters={'number': str})
    for data in df.values:
        recipient = Recipient(dst=data[2])
        firstname = data[1]
        message = Messages(
            text=f"Hello {firstname}, Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem",
            recipients=[recipient],
        )
        job = SmsJob(messages=[message])
        jobs.append(job)

    return jobs


async def send_sms_jobs(jobs: List[SmsJob]):
    async_sdk = SmsClient(True)
    
    res_futures = []
    for job in jobs:
        res = asyncio.ensure_future(async_sdk.client.send_sms(job))
        res_futures.append(res)
    return await asyncio.gather(*res_futures)


if __name__ == "__main__":
    # With load_dotenv, you load the env file needed in the initialize function.
    load_dotenv()
    jobs = initialize()
    loop = asyncio.get_event_loop()
    res = asyncio.ensure_future(send_sms_jobs(jobs))
    loop.run_until_complete(res)
    for x in res.result():
        print(x)
    print(res)



from __future__ import annotations
from typing import List, Optional
from pydantic import BaseModel, validator
from retarus.commons.utils import to_camel_case


class Options(BaseModel):
    src: Optional[str]
    encoding: Optional[str]
    billcode: Optional[str]
    status_requested: Optional[bool]
    flash: Optional[bool]
    customer_ref: Optional[str]
    validity_min: Optional[int]
    max_parts: Optional[int]
    invalid_characters: Optional[str]
    qos: Optional[str]
    job_period: Optional[str]
    duplicate_detection: Optional[bool]
    blackout_periods: Optional[List[str]]

    class Config:
        alias_generator = to_camel_case


class Recipient(BaseModel):
    dst: str
    customer_ref: Optional[str]
    blackout_periods: Optional[List[str]]

    class Config:
        alias_generator = to_camel_case


class Messages(BaseModel):
    text: str
    recipients: List[Recipient]


class SmsJob(BaseModel):
    """
    Create an instance of a SmsJob, set all your needed properties and dispatch it to the Retarus server to send it.

    options: Set special properties how the sms should be processed.
    messages*: set your message that you want to send.
    """
    options: Optional[Options]
    messages: List[Messages]

    class Config:
        alias_generator = to_camel_case

    def exclude_optional_dict(model: BaseModel):
        return {**model.dict(exclude_unset=True), **model.dict(exclude_none=True)}

    def minimal(number: str, message: str) -> SmsJob:
        return SmsJob(messages=[Messages(text=message, recipients=[Recipient(dst=number)])])


class JobReport(BaseModel):
    job_id: str
    src: str
    encoding: str
    billcode: str
    status_requested: bool
    flash: bool
    validity_min: int
    customer_ref: str
    qos: str
    receipt_ts: str
    finished_ts: str
    recipient_ids: List[str]

    class Config:
        alias_generator = to_camel_case


class Client(object):
    def send_sms(self, sms: SmsJob):
        pass

    def get_sms_job(self, job_id: str) -> dict:
        pass

    def filter_sms_jobs(self, *args, **kwargs):
        pass

    def server_version(self):
        pass



from typing import List

from .model import Client

from retarus.commons.region import RegionUri, Region
from ._async import AsyncSmsClient
from .sync import SyncSmsClient


class SmsClient(object):
    __sms_uris: List[RegionUri] = [
        RegionUri(
            region=Region.Europe,
            ha_uri="https://sms4a.eu.retarus.com",
            urls=["https://sms4a.de1.retarus.com", "https://sms4a.de2.retarus.com"],
        )
    ]

    def __init__(self, is_async: bool = False):
        self.is_async: bool = is_async
        if is_async:
            self.client: Client = AsyncSmsClient(self.__sms_uris)
        else:
            self.client: Client = SyncSmsClient(self.__sms_uris)
